#
# spec file for package suse-prime
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           suse-prime
Version:        0.5
Release:        lp151.3.3.1
Summary:        GPU (nvidia/intel) selection for NVIDIA optimus laptops
License:        SUSE-Public-Domain
Group:          System/X11/Utilities
Url:            https://github.com/openSUSE/SUSEPrime
Source0:        https://github.com/openSUSE/SUSEPrime/archive/%{version}.tar.gz#/SUSEPrime-%{version}.tar.gz
Patch0:         U_Corrected-DPI-value-in-xorg-nvidia.conf.patch
Patch1:         U_fix-update-alternatives-for-G05.patch
Recommends:     nvidia_driver
Supplements:    modalias(nvidia_driver:pci:v00008086d*sv*sd*bc03sc*i*)
Conflicts:      suse-prime-alt
BuildArch:      noarch

%description
A collection of shell scripts that makes it possible to use the
NVIDIA GPU on a Optimus Laptop. The switching is similar to
the feature provided by the nvidia-prime package in Ubuntu.

%prep
%setup -n SUSEPrime-%{version}
%patch0 -p1
%patch1 -p1

%build
:

%install
mkdir -p %{buildroot}%{_sysconfdir}/prime
install -m 0644 xorg-intel.conf  %{buildroot}%{_sysconfdir}/prime/
install -m 0644 xorg-intel-intel.conf  %{buildroot}%{_sysconfdir}/prime/
install -m 0644 xorg-nvidia.conf %{buildroot}%{_sysconfdir}/prime/
install -m 0644 09-nvidia-blacklist.conf %{buildroot}%{_sysconfdir}/prime/
install -m 0644 prime-select.service %{buildroot}%{_sysconfdir}/prime/
echo       "undefined"         > %{buildroot}%{_sysconfdir}/prime/current_type
install -D -m 0755 prime-select.sh %{buildroot}%{_sbindir}/prime-select

%preun
if [ "$1" -eq 0 ]; then
   # cleanup before uninstalling the package completely
   %{_sbindir}/prime-select unset
fi

%files
%defattr(-,root,root)
%doc README.md
%{_sysconfdir}/prime
%config %{_sysconfdir}/prime/xorg-intel.conf
%config %{_sysconfdir}/prime/xorg-intel-intel.conf
%config %{_sysconfdir}/prime/xorg-nvidia.conf
%config %{_sysconfdir}/prime/09-nvidia-blacklist.conf
%config %{_sysconfdir}/prime/prime-select.service
%config(noreplace) %{_sysconfdir}/prime/current_type
%{_sbindir}/prime-select

%changelog
* Thu Oct  3 2019 Stefan Dirsch <sndirsch@suse.com>
- U_fix-update-alternatives-for-G05.patch
  * get rid of unsettling update-alternatives error message; latest
    G05 drivers no longer need update-alternatives for libglx
    Xserver module (boo#1152911)
* Mon Apr  1 2019 Stefan Dirsch <sndirsch@suse.com>
- U_Corrected-DPI-value-in-xorg-nvidia.conf.patch
  * Corrected DPI value in xorg-nvidia.conf (boo#1130723)
* Sat Jan 26 2019 sndirsch@suse.com
- fixed URLs in specfile (project location changed on github)
* Sat Jan 26 2019 sndirsch@suse.com
- Update to release 0.5
  * Add various improvements to the original script (by @bubbleguuum)
    1. add bbswitch support to power off NVIDIA card if not in use.
    This is important to save battery when running on Intel and
    to decrease cpu temperature significantly.
    This support is optional, it requires user to make some
    manual modifications to his system using detailed documentation.
    2. add Intel Open Source driver support (xf86-video-intel)
    via new intel2 command-line option.
    This driver has some additional features that users may want.
    3. add the proper BusID for Intel in xorg configuration.
    Without this, Xorg fails to start on some laptops.
    4. fix (via modified xorg-nvidia.conf) for external monitor
    not enumerated by xrandr with the nvidia config.
    On Optimus laptop, the dGPU is usually responsible of managing
    external video ports, including connections via Thunderbolt 3.
  * get-current option for prime-select script
    Show valid options for prime-select script, if driver has not
    been configured yet
- supersedes the following patches
  * 0002-fix-README.patch
  * U_prime-select.sh-bail-out-if-nvidia-xconfig-fails-use.patch
  * 0004-xorg-nvidia.conf-refix-config.patch
  * 0003-prime-select-Show-valid-options-if-driver-has-not-be.patch
  * 0001-Add-various-improvements-to-the-original-script.patch
- %%preun: cleanup before uninstalling the package completely by
  using prime-select's 'unset' option
* Fri Jan 25 2019 sndirsch@suse.com
- 0001-Add-various-improvements-to-the-original-script.patch
  * Add various improvements to the original script
    1. add bbswitch support to power off NVIDIA card if not in use.
    This is important to save battery when running on Intel and
    to decrease cpu temperature significantly.
    This support is optional, it requires user to make some
    manual modifications to his system using detailed documentation.
    2. add Intel Open Source driver support (xf86-video-intel)
    via new intel2 command-line option.
    This driver has some additional features that users may want.
    3. add the proper BusID for Intel in xorg configuration.
    Without this, Xorg fails to start on some laptops.
    4. fix (via modified xorg-nvidia.conf) for external monitor
    not enumerated by xrandr with the nvidia config.
    On Optimus laptop, the dGPU is usually responsible of managing
    external video ports, including connections via Thunderbolt 3.
- 0002-fix-README.patch
  * fix README
- 0003-prime-select-Show-valid-options-if-driver-has-not-be.patch
  * prime-select: Show valid options, if driver has not been
    configured yet.
- 0004-xorg-nvidia.conf-refix-config.patch
  * xorg-nvidia.conf: refix config
* Fri Jan 11 2019 sndirsch@suse.com
- U_prime-select.sh-bail-out-if-nvidia-xconfig-fails-use.patch
  * 'nvidia-xconfig --query-gpu-info' may easily fail due to missing
    NVIDIA kernel modules or alike. Therefore bail out in this case
    with exit 1.
  * There could be more than one NVIDIA card/GPU in the system. Use
    the first detected one for X configuration in that case.
* Thu Jan 10 2019 sndirsch@suse.com
- Update to release 0.3
  * added "query" switch: use 'prime-select query' to check which
    GPU you're currently using
  * removed UseDisplayDevice option from xorg-nvidia.conf which is
    not needed anymore and prevents use of external displays
- supersedes patches
  * U_Fixed-syntax-error-and-handled-not-yet-existing-conf.patch
  * U_adding-query-switch.patch
* Wed Jan  9 2019 sndirsch@suse.com
- U_Fixed-syntax-error-and-handled-not-yet-existing-conf.patch
  * Fixed syntax error and handled not yet existing configurations
* Wed Jan  9 2019 sndirsch@suse.com
- U_adding-query-switch.patch
  * adding "query" switch (boo#1121246)
  * removing line from xorg-nvidia.conf, which is not needed
    anymore and prevents use of external displays
* Mon Nov 12 2018 sndirsch@suse.com
- changed Requires: nvidia_driver to Recommends in order to receive
  more acceptance for integration into (open)SUSE
- added Supplements: nvidia_driver:<intel_PCI_ID>, so package gets
  selected as well when nvidia driver packages are selected on an
  Optimus system
- added proper and valid Group tag
* Tue Oct 16 2018 msrb@suse.com
- Changed License tag to SUSE-Public-Domain - this is the value
  necessary for RPM to accept Public Domain "license".
* Fri Oct 12 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summary.
* Fri Aug 17 2018 msrb@suse.com
- Update to release 0.2 - adapted for X server with provider
  autoconfiguration patch.
* Thu Mar 24 2016 bosim@opensuse.org
- Changed Source URL
* Sun Mar 20 2016 bosim@opensuse.org
- Tagged release 0.1
* Sat Mar 19 2016 tchvatal@suse.com
- Introduce changelog, cleanup a bit
* Sun Feb 14 2016 bo@geekworld.dk
- Using master branch instead of rpm branch
* Sun Nov 22 2015 bo@geekworld.dk
- Initial version
